@@ -21,47 +21,9 @@ from polygenic.data.vcf_accessor import VcfAccessor
 from polygenic.data.csv_accessor import CsvAccessor
 from tqdm import tqdm
 
-def error_print(*args, **kwargs):
-    print(*args, file=sys.stderr, **kwargs)
-
-def error_exit(e):
-    time = datetime.now().strftime("%d/%m/%Y %H:%M:%S")
-    error_print("")
-    error_print("  polygenic ERROR ")
-    error_print("  version: " + version)
-    error_print("  time: " + time)
-    error_print("  command: pgstk " + (" ").join(sys.argv))
-    error_print("  message: ")
-    error_print("")
-    error_print("  " + str(e))
-    error_print("")
-    exit(1)
-
 def expand_path(path: str) -> str:
     return os.path.abspath(os.path.expanduser(path)) if path else ''
 
-def setup_logger(path):
-    logger = logging.getLogger('pgstk')
-
-    log_directory = os.path.dirname(os.path.abspath(os.path.expanduser(path)))
-    if log_directory:
-        try:
-            os.makedirs(log_directory)
-        except OSError:
-            pass
-    logger.setLevel(logging.DEBUG)
-    logging_file_handler = logging.FileHandler(path)
-    logging_file_handler.setLevel(logging.DEBUG)
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-    logging_file_handler.setFormatter(formatter)
-    logger.addHandler(logging_file_handler)
-
-    consoleHandler = logging.StreamHandler()
-    consoleHandler.setFormatter(formatter)
-    logger.addHandler(consoleHandler)
-
-    return logger
-
 ### model tools
 def download(url: str, output_path: str, force: bool=False, progress: bool=False):
     """Downloads file from url
